# Soft Lake

Authors: Massimiliano Cannata, Fabio Lepori, Camilla Capelli
Copyright (c) 2020 IST-SUPSI (www.supsi.ch/ist)
License: GPL v2
version Beta-0.1

[Documentation:](./build/html/index.html)

Soft Lake is a model to estimate Primary Production at hourly rate from monthly profiles.

## Data inputs:

- monthly observations of in-situ profiles measurements along defined depths of Primary Production, Irradiance, Chlorophill-a, Water Temperature

- hourly Irradiance and Wind Speed observations from Weather Station

## Data Outputs:

- Primary Production at hourly rate